@@ -163,9 +163,7 @@ public:
     QVariant toolTip(int column) const
     {
         if (!mSig.isNull()) {
-            if (column == static_cast<int>(UserIDListModel::Column::Status)) {
-                return i18n("class %1", mSig.certClass());
-            } else if (column == static_cast<int>(UserIDListModel::Column::TrustSignatureDomain)) {
+            if (column == static_cast<int>(UserIDListModel::Column::TrustSignatureDomain)) {
                 return Formatting::trustSignature(mSig);
             }
         }
@@ -203,6 +201,11 @@ public:
         return mUid;
     }
 
+    const char *signerKeyId() const
+    {
+        return mSig.signerKeyID();
+    }
+
 private:
     QList<UIDModelItem *> mChildItems;
     QList<QVariant> mItemData;
@@ -328,6 +331,8 @@ QVariant UserIDListModel::data(const QModelIndex &index, int role) const
         return item->toolTip(index.column());
     case Qt::DecorationRole:
         return item->icon(index.column());
+    case UserIDListModel::SignerKeyIdRole:
+        return QVariant::fromValue(item->signerKeyId());
     default:;
     }
 
