@@ -1,5 +1,5 @@
 /*
-    utils/string.cpp
+    utils/stringutils.cpp
 
     This file is part of libkleopatra
     SPDX-FileCopyrightText: 2021 g10 Code GmbH
