@@ -23,8 +23,6 @@ using namespace QGpgME;
 
 #include <stdlib.h>
 
-#include <gpgme++/gpgmepp_version.h>
-
 int main(int argc, char **argv)
 {
     if (GpgME::initializeLibrary(0)) {
@@ -330,10 +328,8 @@ int main(int argc, char **argv)
             Q_ASSERT(lst[1].query() == QStringLiteral("a:b c")); // see, the space got _not_escaped
             lst << QUrl(QStringLiteral("ldap://server:389?a=b,c=DE"));
             Q_ASSERT(lst[2].query() == QStringLiteral("a=b,c=DE")); // the query contains a literal ','
-#if GPGMEPP_VERSION >= 0x11000 // 1.16.0
             lst << QUrl(QStringLiteral("ldap://foo:389?a#ldaps"));
             Q_ASSERT(lst[3].fragment() == QStringLiteral("ldaps"));
-#endif
             // cout << " trying to set: " << lst.toStringList().join(", ").local8Bit() << endl;
             entry->setURLValueList(lst);
             Q_ASSERT(entry->isDirty());
@@ -361,9 +357,7 @@ int main(int argc, char **argv)
             Q_ASSERT(newlst[0].url() == lst[0].url());
             Q_ASSERT(newlst[1].url() == lst[1].url());
             Q_ASSERT(newlst[2].url() == lst[2].url());
-#if GPGMEPP_VERSION >= 0x11000 // 1.16.0
             Q_ASSERT(newlst[3].url() == lst[3].url());
-#endif
 
             // Reset old value
             entry->setURLValueList(val);
